@@ -5,7 +5,7 @@
  * This file contains the implementation of the main KBiff
  * widget
  *
- * $Id: kbiff.cpp,v 1.7 2002/04/14 06:55:22 gran Exp $
+ * $Id: kbiff.cpp,v 1.10 2002/11/02 03:36:35 gran Exp $
  */
 #include "kbiff.h"
 #include <qmovie.h>
@@ -122,6 +122,28 @@ void KBiff::processSetup(const KBiffSetup* setup, bool run)
       disconnect(this, SLOT(saveYourself()));
       kapp->disableSessionManagement();
     }
+
+    // if we are going to be doing status, we might as well create
+    // one now
+    if ( dostatus )
+    {
+      statusList.clear();
+      KBiffMonitor *monitor;
+      for (monitor = monitorList.first(); monitor; monitor = monitorList.next())
+      {
+        statusList.append(new KBiffStatusItem(monitor->getMailboxKey(),
+                                              monitor->newMessages(),
+                                              monitor->curMessages()));
+      }
+      if (status)
+      {
+        status->hide();
+        delete status;
+        status = 0;
+      }
+      status = new KBiffStatus(this, profile, statusList);
+    }
+
     delete setup;
 }
 
@@ -184,11 +206,7 @@ void KBiff::mousePressEvent(QMouseEvent *event)
 {
     // regardless of which button, get rid of the status box
     if (status)
-    {
         status->hide();
-        delete status;
-        status = 0;
-    }
 
     // also, ditch the timer
     if (statusTimer)
@@ -247,18 +265,11 @@ void KBiff::leaveEvent(QEvent *e)
 
     // get rid of the status box if it is activated
     if (status)
-    {
         status->hide();
-        delete status;
-        status = 0;
-    }
 }
 
 void KBiff::popupStatus()
 {
-    if (status)
-        delete status;
-
     // if we don't get rid of the timer, then the very next
     // time we float over the icon, the status box will
     // *not* be activated!
@@ -275,12 +286,12 @@ void KBiff::popupStatus()
         KBiffMonitor *monitor;
         for(monitor = monitorList.first(); monitor; monitor = monitorList.next())
         {
-            statusList.append(new KBiffStatusItem(monitor->getMailboxKey(), monitor->newMessages()));
+            statusList.append(new KBiffStatusItem(monitor->getMailboxKey(), monitor->newMessages(), monitor->curMessages()));
         }
         statusChanged = false;
     }
 
-    status = new KBiffStatus(profile, statusList);
+    status->updateListView(statusList);
     status->popup(QCursor::pos());
 }
 
@@ -495,11 +506,16 @@ void KBiff::haveNewMail(const int num, const QString& the_mailbox)
     // notify if we must
     if (notify)
     {
-        KBiffNotify *notify_dlg = new KBiffNotify(num, the_mailbox);
+        KBiffNotify *notify_dlg = new KBiffNotify(this, num, the_mailbox);
         connect(notify_dlg, SIGNAL(signalLaunchMailClient()),
                 this, SLOT(slotLaunchMailClient()));
         notifyList.append(notify_dlg);
         notify_dlg->show();
+
+        // half-hearted attempt to center this
+        int x = (KApplication::desktop()->width() - notify_dlg->width()) / 2;
+        int y = (KApplication::desktop()->height() - notify_dlg->height()) / 2;
+        notify_dlg->move(x, y);
     }
 }
 
@@ -660,6 +676,7 @@ void KBiff::start()
 void KBiff::popupMenu()
 {
     KPopupMenu *popup = new KPopupMenu(0, "popup");
+    popup->insertTitle(kapp->miniIcon(), profile);
 
     // if secure, disable everything but exit
     if (isSecure == false)
@@ -717,7 +734,7 @@ void KBiff::reset()
     docked    = false;
     isSecure  = false;
 
-    mailClient  = "xmutt";
+    mailClient  = "xmutt -f +%m";
 
     myMUTEX = false;
 }
