@@ -5,7 +5,7 @@
  * This file contains the implementation of KBiffMonitor and
  * associated classes.
  *
- * $Id: kbiffmonitor.cpp,v 1.9 2002/03/25 19:21:28 gran Exp $
+ * $Id: kbiffmonitor.cpp,v 1.13 2002/11/02 03:36:35 gran Exp $
  */
 #include "kbiffmonitor.h"
 
@@ -60,6 +60,7 @@ KBiffMonitor::KBiffMonitor()
       oldTimer(0),
       started(false),
       newCount(0),
+      curCount(-1),
       oldCount(-1),
       firstRun(false),
       key(""),
@@ -360,6 +361,7 @@ void KBiffMonitor::setMailboxIsRead()
     if (b_new_lastModified) lastModified = new_lastModified;
     if (b_new_uidlList)     uidlList     = new_uidlList;
 
+    if (curCount!=-1) curCount+=newCount;
     newCount = 0;
     b_new_lastSize = false;
     b_new_lastRead = false;
@@ -450,7 +452,7 @@ void KBiffMonitor::checkMbox()
 
         // if there are any new messages, consider the state New
         if (newCount > 0)
-            determineState(NewMail);
+          determineState(NewMail);
         else
         {
             if (oldCount == 0)
@@ -529,6 +531,7 @@ void KBiffMonitor::checkPop()
     if (command == "UIDL\r\n")
     {
         determineState(pop->getUidlList());
+        curCount = uidlList.count();
     }
     else
     {
@@ -547,6 +550,14 @@ void KBiffMonitor::checkImap()
     int seq = 1000;
     bool do_login = false;
 
+    // run external client (probably to setup SSL)
+    if (!fetchCommand.isEmpty()) {
+        emit(signal_fetchMail(fetchCommand));
+
+        // sleep a bit to allow the connection to take place
+        sleep(1);
+    }
+
     // connect to the server
     if (imap->active() == false)
     {
@@ -616,6 +627,7 @@ void KBiffMonitor::checkImap()
     else
     {
         newCount = imap->numberOfNewMessages();
+	curCount = imap->numberOfMessages() - newCount;
         if (newCount > 0)
             determineState(NewMail);
         else
@@ -651,23 +663,24 @@ void KBiffMonitor::checkMaildir()
             // determining "new" (or "unread") mail in maildir folders
             // is a *little* tricky.  all mail in the 'new' folder are
             // new, of course... but so is all mail in the 'cur'
-            // folder that doesn't have a ':2,[R|S]' after it.
+            // folder that doesn't have a ':2,[R|S|T]' after it.
             newCount = new_mailbox.count();
+            curCount = cur_mailbox.count();
 
             const QFileInfoList *cur_list = cur_mailbox.entryInfoList();
             QFileInfoListIterator it(*cur_list);
             QFileInfo *info;
 
-            static QRegExp suffix(":2,?R?S?$");
+            static QRegExp suffix(":2,?R?S?T?$");
             while ((info = it.current()))
             {
                 if (info->fileName().findRev(suffix) == -1)
                 {
                     newCount++;
+                    curCount--;
                 }
                 ++it;
             }
-            int cur_count = cur_mailbox.count();
 
             // all messages in 'new' are new
             if (newCount > 0)
@@ -675,7 +688,7 @@ void KBiffMonitor::checkMaildir()
                 determineState(NewMail);
             }
             // failing that, we look for any old ones
-            else if (cur_count > 0)
+            else if (curCount > 0)
             {
                 determineState(OldMail);
             }
@@ -1044,29 +1057,45 @@ void KBiffMonitor::determineState(KBiffUidlList uidl_list)
     // new mail
     for (UIDL = uidl_list.first(); UIDL != 0; UIDL = uidl_list.next())
     {
-      if (uidlList.find(UIDL) == -1)
-        messages++;
-    }
-
-    // if there are any new messages, then notify.. but only if the
-    // state isn't currently NewMail
-    if ((messages > 0) && (mailState != NewMail))
-    {
-      if (!b_new_uidlList || newCount < (int)messages)
+      // If we already have new mail use new_uidlList to se if we have
+      // more new messages
+      if (b_new_uidlList)
       {
-        mailState = NewMail;
-        emit(signal_newMail());
-        emit(signal_newMail(newCount, key));
-        onStateChanged();
+        if (new_uidlList.find(UIDL) == -1)
+          messages++;
+      }
+      else
+      {
+        if (uidlList.find(UIDL) == -1)
+          messages++;
+      }
+    }
+    // if there are any new messages, then notify..
+    if (messages > 0)
+    {
+      mailState = NewMail;
+      emit(signal_newMail());
+      emit(signal_newMail(newCount, key));
+      onStateChanged();
+      // now update newCount
+      if (b_new_uidlList)
+      {
+        // if we have used new_uidlList for a check
+        newCount += messages;
+      }
+      else
+      {
+        // if we have used uidlList for a check
+        newCount = messages;
       }
-      newCount = messages;
       new_uidlList = uidl_list;
       b_new_uidlList = true;
     }
     // this is horrible.  it will reset kbiff to OldMail the very next
     // time a pop3 mailbox is checked.  i don't know of a way around
     // this, though :-(
-    else if (mailState != OldMail)
+    // MZ: what's wrong with that?
+    else if ( (!b_new_uidlList) && mailState != OldMail)
     {
       newCount = 0;
       mailState = OldMail;
@@ -1191,6 +1220,7 @@ int KBiffMonitor::mboxMessages()
     long content_length  = 0;
 
     oldCount = 0;
+    curCount = 0;
 
     if (mbox.open(IO_ReadOnly) == false)
         return 0;
@@ -1232,6 +1262,7 @@ int KBiffMonitor::mboxMessages()
             if (strcmp(buffer, "Subject: DON'T DELETE THIS MESSAGE -- FOLDER INTERNAL DATA\n") == 0)
             {
                 oldCount--;
+		curCount--;
             }
             else
             {
@@ -1272,8 +1303,11 @@ int KBiffMonitor::mboxMessages()
 
                     oldCount++;
 
-                    if (!msg_read)
+                    if (!msg_read) {
                         count++;
+		    } else {
+		        curCount++;
+		    }
                 } 
             }
         }//in header
@@ -1286,7 +1320,6 @@ int KBiffMonitor::mboxMessages()
     }//while
 
     mbox.close();
-
     return count;
 }
 
