@@ -2,7 +2,7 @@
  * kbiffmonitor.h
  * Copyright (C) 1999-2001 Kurt Granroth <granroth@kde.org>
  *
- * $Id: kbiffmonitor.h,v 1.6 2001/10/23 19:52:18 gran Exp $
+ * $Id: kbiffmonitor.h,v 1.7 2002/06/09 23:52:07 gran Exp $
  *
  */
 #ifndef KBIFFMONITOR_H
@@ -165,7 +165,7 @@ typedef enum
  *
  * @short A "biff" class that monitors local and remote mailboxes
  * @author Kurt Granroth <granroth@kde.org>
- * @version $Id: kbiffmonitor.h,v 1.6 2001/10/23 19:52:18 gran Exp $
+ * @version $Id: kbiffmonitor.h,v 1.7 2002/06/09 23:52:07 gran Exp $
  */
 class KBiffMonitor : public QObject
 {
@@ -214,6 +214,11 @@ public:
      */
     int newMessages() { return newCount; }
 
+    /**
+     * Returns the number of messages for the current mailbox
+     */
+    int curMessages() { return curCount; }
+
 
     void saveConfig();
     void readConfig();
@@ -391,6 +396,7 @@ private:
     int     oldTimer;
     bool    started;
     int     newCount;
+    int     curCount;
     int     oldCount;
     bool    firstRun;
 
