@@ -5,7 +5,7 @@
  * This file contains the implementation of the setup dialog
  * class for KBiff.
  *
- * $Id: setupdlg.cpp,v 1.8 2002/04/14 06:55:22 gran Exp $
+ * $Id: setupdlg.cpp,v 1.10 2002/11/02 03:36:35 gran Exp $
  */
 #include "setupdlg.h"
 
@@ -517,6 +517,14 @@ KBiffGeneralTab::KBiffGeneralTab(const QString& profile, QWidget *parent)
   QLabel *mail_label = new QLabel(i18n("&Mail client:"), this);
   editCommand = new QLineEdit(this);
   mail_label->setBuddy(editCommand);
+  whatsthis = i18n(
+      "This is the mail client that KBiff was use when you click "
+      "on the icon or the Mailer button.  If it's not in your path, "
+      "then you must specify the location using an absolute path. "
+      "This recognizes the <b>%m</b> and <b>%u</b> arguments.  The "
+      "first is replaced with the first mailbox containing new mail "
+      "and the latter is replaced with the mailbox's URL.");
+  QWhatsThis::add(editCommand, whatsthis);
 
   // do we dock automatically?
   checkDock = new QCheckBox(i18n("Doc&k in panel"), this);
@@ -714,11 +722,11 @@ static QString justIconName(const QString& icon_name)
   // we first test if the basename (filename without extensions) is
   // the same as the filename.  if it is, then we are perfect.  no
   // need to do anything further
-  if ( info.baseName(true) == info.fileName() )
+  if ( info.baseName() == info.fileName() )
     return icon_name;
 
   // now we see if we can load based just on the basename
-  QPixmap icon = KGlobal::iconLoader()->loadIcon( info.baseName(true), KIcon::User );
+  QPixmap icon = KGlobal::iconLoader()->loadIcon( info.baseName(), KIcon::User );
 
   // if it's null, then it's in a non-standard path so we must use an
   // absolute path.  no need to go further
@@ -727,14 +735,14 @@ static QString justIconName(const QString& icon_name)
 
   // now we know that the icon loader can find it.. but is it the same
   // one as the one the user picked?
-  if ( KGlobal::iconLoader()->iconPath( info.baseName(true), KIcon::User ) !=
+  if ( KGlobal::iconLoader()->iconPath( info.baseName(), KIcon::User ) !=
        KGlobal::iconLoader()->iconPath( icon_name, KIcon::User ) )
     return icon_name;
 
   // FINALLY done!  if we got this far, then we know that the icon
   // loader can handle just the name and that the icon returned is the
   // same one that the user wanted.  whew!
-  return info.baseName(true);
+  return info.baseName();
 }
 
 void KBiffGeneralTab::saveConfig(const QString& profile)
@@ -1784,7 +1792,7 @@ KBiffAboutTab::KBiffAboutTab(QWidget *parent)
                       SLOT(homepage(const QString&)));
 
   QLabel *version_label = new QLabel(this);
-  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2002\nKurt Granroth").arg("3.6.1"));
+  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2002\nKurt Granroth").arg("3.6.3"));
 
   KURLLabel *email_label = new KURLLabel(this);
   email_label->setText("granroth@kde.org");
