@@ -5,7 +5,7 @@
  * This file contains the implementation of the KBiffStatus
  * widget
  *
- * $Id: status.cpp,v 1.5 2002/03/25 19:21:28 gran Exp $
+ * $Id: status.cpp,v 1.7 2002/11/02 03:36:35 gran Exp $
  */
 #include "status.h"
 
@@ -18,8 +18,8 @@
 #include <qlistview.h>
 #include <qpoint.h>
 
-KBiffStatus::KBiffStatus(const QString& profile, const KBiffStatusList& list)
-    : QFrame(0, 0, WType_Popup),
+KBiffStatus::KBiffStatus(QWidget *parent, const QString& profile, const KBiffStatusList& list)
+    : QFrame(parent, 0, WType_Popup),
       _listView(new QListView(this))
 {
     setFrameStyle(WinPanel|Raised);
@@ -29,27 +29,16 @@ KBiffStatus::KBiffStatus(const QString& profile, const KBiffStatusList& list)
 
     _listView->addColumn(i18n("Mailbox"));
     _listView->addColumn(i18n("New"));
+    _listView->addColumn(i18n("Old"));
     _listView->setColumnAlignment(1, AlignRight);
+    _listView->setColumnAlignment(2, AlignRight);
     _listView->setSorting(1, FALSE);
     _listView->setFrameStyle(QFrame::WinPanel | QFrame::Raised);
     _listView->setVScrollBarMode(QScrollView::AlwaysOff);
     _listView->setHScrollBarMode(QScrollView::AlwaysOff);
     _listView->header()->hide();
 
-    KBiffStatusListIterator it(list);
-    for(it.toFirst(); it.current(); ++it)
-    {
-        if (it.current()->newMessages() == "-1")
-        {
-            new QListViewItem(_listView, it.current()->mailbox(),
-                              i18n("Disabled"));
-        }
-        else
-        {
-            new QListViewItem(_listView, it.current()->mailbox(),
-                              it.current()->newMessages());
-        }
-    }
+    updateListView(list);
 
     int list_height = (_listView->firstChild()->height() * list.count()) + 10;
     _listView->setFixedSize(_listView->sizeHint().width() + 5, list_height);
@@ -64,6 +53,25 @@ KBiffStatus::~KBiffStatus()
 {
 }
 
+void KBiffStatus::updateListView(const KBiffStatusList& list)
+{
+    _listView->clear();
+    KBiffStatusListIterator it(list);
+    for(it.toFirst(); it.current(); ++it)
+    {
+        if (it.current()->newMessages() == "-1")
+        {
+            new QListViewItem(_listView, it.current()->mailbox(),
+                              i18n("Disabled"));
+        }
+        else
+        {
+             new QListViewItem(_listView, it.current()->mailbox(),
+                               it.current()->newMessages(),it.current()->curMessages());
+        }
+    }
+}
+
 void KBiffStatus::popup(const QPoint& pos)
 {
     QWidget *desktop = KApplication::desktop();
@@ -92,10 +100,18 @@ void KBiffStatus::popup(const QPoint& pos)
     move(x, y);
 }
 
+KBiffStatusItem::KBiffStatusItem(const QString& mailbox, const int num_new,const int num_cur)
+    : QObject(),
+      _mailbox(mailbox),
+      _newMessages(QString().setNum(num_new)),
+      _curMessages((num_cur==-1)?QString("?"):QString().setNum(num_cur))
+{
+}
 KBiffStatusItem::KBiffStatusItem(const QString& mailbox, const int num_new)
     : QObject(),
       _mailbox(mailbox),
-      _newMessages(QString().setNum(num_new))
+      _newMessages(QString().setNum(num_new)),
+      _curMessages(QString("?"))
 {
 }
 
