@@ -5,7 +5,7 @@
  * This file contains the declaration of the KBiffStatus
  * widget.
  *
- * $Id: status.h,v 1.2 2001/03/24 18:50:21 gran Exp $
+ * $Id: status.h,v 1.4 2002/11/02 03:36:35 gran Exp $
  */
 #ifndef KBIFFSTATUS_H 
 #define KBIFFSTATUS_H 
@@ -26,14 +26,17 @@ class KBiffStatusItem : QObject
     Q_OBJECT
 public:
 	KBiffStatusItem(const QString& mailbox, const int num_new);
+	KBiffStatusItem(const QString& mailbox, const int num_new,const int num_cur);
 	virtual ~KBiffStatusItem();
 
 	QString mailbox() const { return _mailbox; }
 	QString newMessages() const { return _newMessages; }
+	QString curMessages() const { return _curMessages; }
 
 protected:
 	QString _mailbox;
 	QString _newMessages;
+	QString _curMessages;
 };
 
 typedef QList<KBiffStatusItem>         KBiffStatusList;
@@ -43,9 +46,10 @@ class KBiffStatus : public QFrame
 {
 	Q_OBJECT
 public:
-	KBiffStatus(const QString& profile, const KBiffStatusList& list);
+	KBiffStatus(QWidget *parent, const QString& profile, const KBiffStatusList& list);
 	virtual ~KBiffStatus();
 
+	void updateListView(const KBiffStatusList& list);
 	void popup(const QPoint& pos);
 
 protected:
